parentlock-sh-functions
=======================

Parentlock allows sharing a lock among child processes
of given pid. It is useful for shell scripting where there are
lots of nested script calls and we want to share a lock through the
parent - child relationship.

When the parent process get parentlock then as long as the parent process exist
any its child / grandchild / grand-grand-...child process
just check that PID in parentlock is their parent and does not lock.
Note that parentlock expires when the process that got lock finishes.
It means that unlocking is optional and the main function of unlocking
is to clean up the stale lock file.


Example shell script that uses parentlock-sh-functions
________________________________________________

# define lock file
PARENTLOCK_FILE=.mylock
export PARENTLOCK_FILE

. parentlock-sh-functions

# (optional) set lockfile cleanup trap on INT TERM EXIT
# note: if you set your own trap, do not call parentlock_set_unlock_workdir_trap_on_int_term_exit
# because its trap will be overridden.
# Instead, call in your trap parentlock_unlock_workdir_safe
parentlock_set_unlock_workdir_trap_on_int_term_exit

# lock
parentlock_lock_workdir_or_exit
...
# script body
...

# unlock (optional)
parentlock_unlock_workdir_safe


LICENSE
_______
public domain or Perl Artistic 2.0
